@@ -1739,18 +1739,18 @@ create_toolbar (DatesData *  d)
 	toolbar = gtk_hbox_new (FALSE, 3);
 	gtk_widget_show (toolbar);
 
-	d->TBNew = gtk_button_new_from_stock ("gtk-new");
+	d->TBNew = gtk_button_new_from_stock (GTK_STOCK_NEW);
 	gtk_widget_show (d->TBNew);
 	gtk_box_pack_start (GTK_BOX (toolbar), d->TBNew, FALSE, FALSE, 0);
 	gtk_button_set_focus_on_click (GTK_BUTTON (d->TBNew), FALSE);
 
-	d->TBEdit = gtk_button_new_from_stock ("gtk-edit");
+	d->TBEdit = gtk_button_new_from_stock (GTK_STOCK_EDIT);
 	gtk_box_pack_start (GTK_BOX (toolbar), d->TBEdit, FALSE, FALSE, 0);
 	gtk_widget_set_sensitive (d->TBEdit, FALSE);
 	gtk_widget_show (d->TBEdit);
 	gtk_button_set_focus_on_click (GTK_BUTTON (d->TBEdit), FALSE);
 
-	d->TBDelete = gtk_button_new_from_stock ("gtk-delete");
+	d->TBDelete = gtk_button_new_from_stock (GTK_STOCK_DELETE);
 	gtk_box_pack_start (GTK_BOX (toolbar), d->TBDelete, FALSE, FALSE, 0);
 	gtk_widget_set_sensitive (d->TBDelete, FALSE);
 	gtk_widget_show (d->TBDelete);
@@ -1760,36 +1760,40 @@ create_toolbar (DatesData *  d)
 	gtk_box_pack_start (GTK_BOX (toolbar), d->TBBack, FALSE, FALSE, 0);
 	gtk_widget_show (d->TBBack);
 	gtk_button_set_focus_on_click (GTK_BUTTON (d->TBBack), FALSE);
-	image = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_BUTTON);
-	gtk_button_set_image (GTK_BUTTON (d->TBBack), image);
+	image = gtk_image_new_from_stock (GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON);
+	gtk_container_add (GTK_CONTAINER (d->TBBack), image);
+	gtk_widget_show (image);
 
 	d->TBToday = gtk_button_new_with_mnemonic (_("_Today"));
 	gtk_widget_show (d->TBToday);
 	gtk_box_pack_start (GTK_BOX (toolbar), d->TBToday, FALSE, FALSE, 0);
 	gtk_button_set_focus_on_click (GTK_BUTTON (d->TBToday), FALSE);
-	image = gtk_image_new_from_stock ("gtk-home", GTK_ICON_SIZE_BUTTON);
+	image = gtk_image_new_from_stock (GTK_STOCK_HOME, GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image (GTK_BUTTON (d->TBToday), image);
 
 	d->TBForward = gtk_button_new ();
 	gtk_widget_show (d->TBForward);
 	gtk_box_pack_start (GTK_BOX (toolbar), d->TBForward, FALSE, FALSE, 0);
 	gtk_button_set_focus_on_click (GTK_BUTTON (d->TBForward), FALSE);
-	image = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_BUTTON);
-	gtk_button_set_image (GTK_BUTTON (d->TBForward), image);
+	image = gtk_image_new_from_stock (GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON);
+	gtk_container_add (GTK_CONTAINER (d->TBForward), image);
+	gtk_widget_show (image);
 
 	d->TBZoomOut = gtk_button_new ();
 	gtk_widget_show (d->TBZoomOut);
 	gtk_box_pack_start (GTK_BOX (toolbar), d->TBZoomOut, FALSE, FALSE, 0);
 	gtk_button_set_focus_on_click (GTK_BUTTON (d->TBZoomOut), FALSE);
-	image = gtk_image_new_from_stock ("gtk-zoom-out", GTK_ICON_SIZE_BUTTON);
-	gtk_button_set_image (GTK_BUTTON (d->TBZoomOut), image);
+	image = gtk_image_new_from_stock (GTK_STOCK_ZOOM_OUT, GTK_ICON_SIZE_BUTTON);
+	gtk_container_add (GTK_CONTAINER (d->TBZoomOut), image);
+	gtk_widget_show (image);
 
 	d->TBZoomIn = gtk_button_new ();
 	gtk_widget_show (d->TBZoomIn);
 	gtk_box_pack_start (GTK_BOX (toolbar), d->TBZoomIn, FALSE, FALSE, 0);
 	gtk_button_set_focus_on_click (GTK_BUTTON (d->TBZoomIn), FALSE);
-	image = gtk_image_new_from_stock ("gtk-zoom-in", GTK_ICON_SIZE_BUTTON);
-	gtk_button_set_image (GTK_BUTTON (d->TBZoomIn), image);
+	image = gtk_image_new_from_stock (GTK_STOCK_ZOOM_IN, GTK_ICON_SIZE_BUTTON);
+	gtk_container_add (GTK_CONTAINER (d->TBZoomIn), image);
+	gtk_widget_show (image);
 
 	g_signal_connect (G_OBJECT (d->TBNew), "clicked",
 					  G_CALLBACK (dates_new_cb),
